@@ -1,5 +1,6 @@
 //! Python bindings for css-inline
 #![warn(
+    clippy::pedantic,
     clippy::doc_markdown,
     clippy::redundant_closure,
     clippy::explicit_iter_loop,
@@ -18,26 +19,29 @@
     unused_extern_crates,
     unused_import_braces,
     unused_qualifications,
-    variant_size_differences
+    variant_size_differences,
+    rust_2018_idioms,
+    rust_2018_compatibility
 )]
 use css_inline as rust_inline;
 use pyo3::{create_exception, exceptions, prelude::*, types::PyList, wrap_pyfunction};
 use rayon::prelude::*;
 use std::borrow::Cow;
 
-const MODULE_DOCSTRING: &str = "Fast CSS inlining written in Rust";
 const INLINE_ERROR_DOCSTRING: &str = "An error that can occur during CSS inlining";
 
-create_exception!(css_inline, InlineError, exceptions::ValueError);
+create_exception!(css_inline, InlineError, exceptions::PyValueError);
 
 struct InlineErrorWrapper(rust_inline::InlineError);
 
 impl From<InlineErrorWrapper> for PyErr {
     fn from(error: InlineErrorWrapper) -> Self {
         match error.0 {
-            rust_inline::InlineError::IO(error) => InlineError::py_err(error.to_string()),
-            rust_inline::InlineError::Network(error) => InlineError::py_err(error.to_string()),
-            rust_inline::InlineError::ParseError(message) => InlineError::py_err(message),
+            rust_inline::InlineError::IO(error) => InlineError::new_err(error.to_string()),
+            rust_inline::InlineError::Network(error) => InlineError::new_err(error.to_string()),
+            rust_inline::InlineError::ParseError(message) => {
+                InlineError::new_err(message.to_string())
+            }
         }
     }
 }
@@ -46,7 +50,7 @@ struct UrlError(url::ParseError);
 
 impl From<UrlError> for PyErr {
     fn from(error: UrlError) -> Self {
-        exceptions::ValueError::py_err(error.0.to_string())
+        exceptions::PyValueError::new_err(error.0.to_string())
     }
 }
 
@@ -154,14 +158,17 @@ fn inline_many(
     inline_many_impl(&inliner, htmls)
 }
 
-fn inline_many_impl(inliner: &rust_inline::CSSInliner, htmls: &PyList) -> PyResult<Vec<String>> {
+fn inline_many_impl(
+    inliner: &rust_inline::CSSInliner<'_>,
+    htmls: &PyList,
+) -> PyResult<Vec<String>> {
     // Extract strings from the list. It will fail if there is any non-string value
-    let extracted: Result<Vec<_>, _> = htmls.iter().map(|item| item.extract::<&str>()).collect();
-    let inlined: Result<Vec<_>, _> = extracted?
+    let extracted: Result<Vec<_>, _> = htmls.iter().map(pyo3::PyAny::extract::<&str>).collect();
+    let output: Result<Vec<_>, _> = extracted?
         .par_iter()
         .map(|html| inliner.inline(html))
         .collect();
-    Ok(inlined.map_err(InlineErrorWrapper)?)
+    Ok(output.map_err(InlineErrorWrapper)?)
 }
 
 #[allow(dead_code)]
@@ -169,15 +176,15 @@ mod build {
     include!(concat!(env!("OUT_DIR"), "/built.rs"));
 }
 
+/// Fast CSS inlining written in Rust
 #[pymodule]
-fn css_inline(py: Python, module: &PyModule) -> PyResult<()> {
+fn css_inline(py: Python<'_>, module: &PyModule) -> PyResult<()> {
     module.add_class::<CSSInliner>()?;
     module.add_wrapped(wrap_pyfunction!(inline))?;
     module.add_wrapped(wrap_pyfunction!(inline_many))?;
     let inline_error = py.get_type::<InlineError>();
     inline_error.setattr("__doc__", INLINE_ERROR_DOCSTRING)?;
     module.add("InlineError", inline_error)?;
-    module.add("__doc__", MODULE_DOCSTRING)?;
     module.add("__build__", pyo3_built::pyo3_built!(py, build))?;
     Ok(())
 }
